<?php
/**
 * Blocks Initializer
 *
 * Enqueue CSS/JS of all the blocks.
 *
 * @since   1.0.0
 * @package CGB
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Load Ttextdomain Languages
load_plugin_textdomain( 'srxgb', false, basename( __DIR__ ) . '/languages' );


// set srxgb custom block category
function srxgb_register_block_category( $categories, $post ) {

		$categories = array_merge(
			$categories,
			array(
				array(
					'slug'  => 'srxgb',
					'title' => __('Easy Blocks pro AddOns', 'srxgb') ,
				),
			)
		);

	return $categories;
}

add_filter( 'block_categories',  'srxgb_register_block_category', 10, 2 );


/**
 * Enqueue Gutenberg block assets for both frontend + backend.
 *
 * @uses {wp-editor} for WP editor styles.
 * @since 1.0.0
 */
function seerox_guten_block_cgb_block_assets() { // phpcs:ignore

	// fontawesome
	wp_enqueue_style(
		'srxgb-fontawesome-css', // Handle.
		plugins_url( 'assets/css/all.min.css', dirname( __FILE__ ) )
	);
	// bootstrap
	wp_enqueue_style(
		'srxgb-bootstrap-css', // Handle.
		plugins_url( 'assets/css/bootstrap.min.css', dirname( __FILE__ ) )
	);
	wp_enqueue_script( 'srxgb-script-bootstrap', plugins_url( 'assets/js/bootstrap.min.js', dirname( __FILE__ ) ), array('jquery'), null, true );

	// Styles.
	wp_enqueue_style(
		'seerox_guten_block-cgb-style-css', // Handle.
		plugins_url( 'dist/blocks.style.build.css', dirname( __FILE__ ) ), // Block style CSS.
		array( 'wp-editor' ), // Dependency to include the CSS after it.
		filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.style.build.css' ) // Version: File modification time.
	);
}

// Hook: Frontend assets.
add_action( 'enqueue_block_assets', 'seerox_guten_block_cgb_block_assets' );



/**
 * Enqueue Gutenberg block assets for backend editor.
 *
 * @uses {wp-blocks} for block type registration & related functions.
 * @uses {wp-element} for WP Element abstraction — structure of blocks.
 * @uses {wp-i18n} to internationalize the block's text.
 * @uses {wp-editor} for WP editor styles.
 * @since 1.0.0
 */
function seerox_guten_block_cgb_editor_assets() { // phpcs:ignore
	// Scripts.
	wp_enqueue_script(
		'seerox_guten_block-cgb-block-js', // Handle.
		plugins_url( '/dist/blocks.build.js', dirname( __FILE__ ) ), // Block.build.js: We register the block here. Built with Webpack.
		array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor' ), // Dependencies, defined above.
		filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.build.js' ), // Version: File modification time.
		true // Enqueue the script in the footer.
	);

	// Styles.
	wp_enqueue_style(
		'seerox_guten_block-cgb-block-editor-css', // Handle.
		plugins_url( 'dist/blocks.editor.build.css', dirname( __FILE__ ) ), // Block editor CSS.
		array( 'wp-edit-blocks' ), // Dependency to include the CSS after it.
		filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.editor.build.css' ) // Version: File modification time.
	);
}

// Hook: Editor assets.
add_action( 'enqueue_block_editor_assets', 'seerox_guten_block_cgb_editor_assets' );


